<?php
/**
 * An interface for city-information (database) wrapper
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2015 City Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface CityInformationWrapper extends DatabaseWrapper {
	/**
	 * 'Registers' a new city id along with data provided in the city instance.
	 * This may sound confusing but avoids double code very nicely...
	 *
	 * @param	$cityInstance		A city instance
	 * @param	$requestInstance	An instance of a Requestable class
	 * @return	void
	 */
	function registerCityId (BaseCityDaemon $cityInstance, Requestable $requestInstance);

	/**
	 * Checks whether there is an entry for given city instance
	 *
	 * @param	$cityInstance	An instance of a CityHelper class
	 * @return	$isFound		Whether a city id has been found for this city
	 */
	function ifCityDataIsFound (CityHelper $cityInstance);

	/**
	 * Removes non-data from given array.
	 *
	 * @param	$data	An array with possible non-data that needs to be removed.
	 * @return	$data	A cleaned up array with only data.
	 */
	function removeNonPublicDataFromArray(array $data);

	/**
	 * Checks whether the user has already founded a city
	 *
	 * @return	$hasFounded		Whether the user has already founded a city
	 */
	function ifUserHasFoundedCity ();

	/**
	 * Checks whether the given city name is taken
	 *
	 * @para	$cityName	Name of city
	 * @return	$isTaken	Whether the given city name is taken
	 */
	function ifCityExists ($cityName);

	/**
	 * Creates a city from given request
	 *
	 * @para	$requestInstance	An instance of a Requestable class
	 * @return	void
	 */
	function createCityByRequest (Requestable $requestInstance);
}

// [EOF]
?>
