<?php
/**
 * An interface for "city-helper" classes
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2015 City Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface CityHelper extends Helper, AddableCriteria {
	/**
	 * Initializes the city daemon
	 *
	 * @return	void
	 */
	function bootstrapInitCityDaemon ();

	/**
	 * Method to "bootstrap" the city. This step does also apply provided
	 * command-line arguments stored in the request instance. You should now
	 * get it from calling $this->getRequestInstance().
	 *
	 * @return	void
	 */
	function doBootstrapping ();

	/**
	 * Outputs the console teaser. This should only be executed on startup or
	 * full restarts. This method generates some space around the teaser.
	 *
	 * @return	void
	 */
	function outputConsoleTeaser ();

	/**
	 * Add some city-specific filters
	 *
	 * @return	void
	 */
	function addExtraCityFilters ();

	/**
	 * Activates the city daemon by doing some final preparation and setting
	 * $cityIsActive to TRUE.
	 *
	 * @param	$requestInstance	A Requestable class
	 * @param	$responseInstance	A Responseable class
	 * @return	void
	 */
	function activateCityDaemon (Requestable $requestInstance, Responseable $responseInstance);

	/**
	 * Updates/refreshes city data (e.g. state).
	 *
	 * @return	void
	 */
	function updateCityData ();

	/**
	 * Adds extra tasks to the given handler for this city
	 *
	 * @param	$handlerInstance	An instance of a HandleableTask class
	 * @return	void
	 */
	function addExtraTasks (HandleableTask $handlerInstance);

	/**
	 * Checks whether at least one map requires expansion
	 *
	 * @return	$requiresExpansion	Whether a map requires expansion
	 */
	function isMapPendingExpansion ();
}

// [EOF]
?>
